@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -84,7 +84,7 @@ __all__ = ("WorkDocsClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -120,7 +120,7 @@ class Exceptions:
 
 class WorkDocsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html)
     """
 
@@ -139,7 +139,7 @@ class WorkDocsClient(BaseClient):
         Aborts the upload of the specified document version that was previously
         initiated by  InitiateDocumentVersionUpload.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#abort_document_version_upload)
         """
 
@@ -149,7 +149,7 @@ class WorkDocsClient(BaseClient):
         """
         Activates the specified user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.activate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.activate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#activate_user)
         """
 
@@ -157,14 +157,14 @@ class WorkDocsClient(BaseClient):
         self,
         *,
         ResourceId: str,
-        Principals: List["SharePrincipalTypeDef"],
+        Principals: Sequence["SharePrincipalTypeDef"],
         AuthenticationToken: str = None,
         NotificationOptions: "NotificationOptionsTypeDef" = None
     ) -> AddResourcePermissionsResponseTypeDef:
         """
         Creates a set of permissions for the specified folder or document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#add_resource_permissions)
         """
 
@@ -172,7 +172,7 @@ class WorkDocsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#can_paginate)
         """
 
@@ -191,7 +191,7 @@ class WorkDocsClient(BaseClient):
         """
         Adds a new comment to the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_comment)
         """
 
@@ -199,7 +199,7 @@ class WorkDocsClient(BaseClient):
         self,
         *,
         ResourceId: str,
-        CustomMetadata: Dict[str, str],
+        CustomMetadata: Mapping[str, str],
         AuthenticationToken: str = None,
         VersionId: str = None
     ) -> Dict[str, Any]:
@@ -207,7 +207,7 @@ class WorkDocsClient(BaseClient):
         Adds one or more custom properties to the specified resource (a folder,
         document, or version).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_custom_metadata)
         """
 
@@ -217,12 +217,12 @@ class WorkDocsClient(BaseClient):
         """
         Creates a folder with the specified name and parent folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_folder)
         """
 
     def create_labels(
-        self, *, ResourceId: str, Labels: List[str], AuthenticationToken: str = None
+        self, *, ResourceId: str, Labels: Sequence[str], AuthenticationToken: str = None
     ) -> Dict[str, Any]:
         """
         Adds the specified list of labels to the given resource (a document or folder)
@@ -231,7 +231,7 @@ class WorkDocsClient(BaseClient):
         **Request Syntax** response = client.create_labels( ResourceId='string',
         Labels=[ ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_labels)
         """
 
@@ -246,7 +246,7 @@ class WorkDocsClient(BaseClient):
         """
         Configure Amazon WorkDocs to use Amazon SNS notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_notification_subscription)
         """
 
@@ -266,7 +266,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a user in a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_user)
         """
 
@@ -275,7 +275,7 @@ class WorkDocsClient(BaseClient):
         Deactivates the specified user, which revokes the user's access to Amazon
         WorkDocs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#deactivate_user)
         """
 
@@ -285,7 +285,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified comment from the document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_comment)
         """
 
@@ -295,13 +295,13 @@ class WorkDocsClient(BaseClient):
         ResourceId: str,
         AuthenticationToken: str = None,
         VersionId: str = None,
-        Keys: List[str] = None,
+        Keys: Sequence[str] = None,
         DeleteAll: bool = None
     ) -> Dict[str, Any]:
         """
         Deletes custom metadata from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_custom_metadata)
         """
 
@@ -309,7 +309,7 @@ class WorkDocsClient(BaseClient):
         """
         Permanently deletes the specified document and its associated metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_document)
         """
 
@@ -317,7 +317,7 @@ class WorkDocsClient(BaseClient):
         """
         Permanently deletes the specified folder and its contents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder)
         """
 
@@ -325,7 +325,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the contents of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder_contents)
         """
 
@@ -334,13 +334,13 @@ class WorkDocsClient(BaseClient):
         *,
         ResourceId: str,
         AuthenticationToken: str = None,
-        Labels: List[str] = None,
+        Labels: Sequence[str] = None,
         DeleteAll: bool = None
     ) -> Dict[str, Any]:
         """
         Deletes the specified list of labels from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_labels)
         """
 
@@ -348,7 +348,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified subscription from the specified organization.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_notification_subscription)
         """
 
@@ -356,7 +356,7 @@ class WorkDocsClient(BaseClient):
         """
         Deletes the specified user from a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_user)
         """
 
@@ -377,7 +377,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the user activities in a specified time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_activities)
         """
 
@@ -393,7 +393,7 @@ class WorkDocsClient(BaseClient):
         """
         List all the comments for the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_comments)
         """
 
@@ -410,7 +410,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves the document versions for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_document_versions)
         """
 
@@ -430,7 +430,7 @@ class WorkDocsClient(BaseClient):
         Describes the contents of the specified folder, including its documents and
         subfolders.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_folder_contents)
         """
 
@@ -446,7 +446,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the groups specified by the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_groups)
         """
 
@@ -456,7 +456,7 @@ class WorkDocsClient(BaseClient):
         """
         Lists the specified notification subscriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_notification_subscriptions)
         """
 
@@ -472,7 +472,7 @@ class WorkDocsClient(BaseClient):
         """
         Describes the permissions of a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_resource_permissions)
         """
 
@@ -483,7 +483,7 @@ class WorkDocsClient(BaseClient):
         Describes the current user's special folders; the `RootFolder` and the
         `RecycleBin`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_root_folders)
         """
 
@@ -504,21 +504,21 @@ class WorkDocsClient(BaseClient):
         """
         Describes the specified users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_users)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#generate_presigned_url)
         """
 
@@ -527,7 +527,7 @@ class WorkDocsClient(BaseClient):
         Retrieves details of the current user for whom the authentication token was
         generated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_current_user)
         """
 
@@ -541,7 +541,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves details of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document)
         """
 
@@ -558,7 +558,7 @@ class WorkDocsClient(BaseClient):
         Retrieves the path information (the hierarchy from the root folder) for the
         requested document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_path)
         """
 
@@ -574,7 +574,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves version metadata for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_version)
         """
 
@@ -584,7 +584,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves the metadata of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder)
         """
 
@@ -601,7 +601,7 @@ class WorkDocsClient(BaseClient):
         Retrieves the path information (the hierarchy from the root folder) for the
         specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder_path)
         """
 
@@ -617,7 +617,7 @@ class WorkDocsClient(BaseClient):
         """
         Retrieves a collection of resources, including folders and documents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.get_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.get_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_resources)
         """
 
@@ -636,7 +636,7 @@ class WorkDocsClient(BaseClient):
         """
         Creates a new document object and version object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#initiate_document_version_upload)
         """
 
@@ -646,7 +646,7 @@ class WorkDocsClient(BaseClient):
         """
         Removes all the permissions from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_all_resource_permissions)
         """
 
@@ -661,7 +661,7 @@ class WorkDocsClient(BaseClient):
         """
         Removes the permission for the specified principal from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_resource_permission)
         """
 
@@ -677,7 +677,7 @@ class WorkDocsClient(BaseClient):
         """
         Updates the specified attributes of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.update_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.update_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document)
         """
 
@@ -692,7 +692,7 @@ class WorkDocsClient(BaseClient):
         """
         Changes the status of the document version to ACTIVE.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document_version)
         """
 
@@ -708,7 +708,7 @@ class WorkDocsClient(BaseClient):
         """
         Updates the specified attributes of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.update_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.update_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_folder)
         """
 
@@ -729,7 +729,7 @@ class WorkDocsClient(BaseClient):
         Updates the specified attributes of the specified user, and grants or revokes
         administrative privileges to the Amazon WorkDocs site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_user)
         """
 
@@ -738,7 +738,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_activities"]
     ) -> DescribeActivitiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
@@ -747,7 +747,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_comments"]
     ) -> DescribeCommentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
@@ -756,7 +756,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_document_versions"]
     ) -> DescribeDocumentVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
@@ -765,14 +765,14 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_folder_contents"]
     ) -> DescribeFolderContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_groups"]) -> DescribeGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
@@ -781,7 +781,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_notification_subscriptions"]
     ) -> DescribeNotificationSubscriptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
@@ -790,7 +790,7 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_resource_permissions"]
     ) -> DescribeResourcePermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
@@ -799,13 +799,13 @@ class WorkDocsClient(BaseClient):
         self, operation_name: Literal["describe_root_folders"]
     ) -> DescribeRootFoldersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_users"]) -> DescribeUsersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
